import os
from pathlib import Path
from sunpeek.components import WPDFluidDefinition, CoolPropFluidDefinition
from sunpeek.components.fluids import WPDModelPure

raw_data_dir = Path(__file__).with_name('raw_data')

wpd_fluids = [
    WPDFluidDefinition('Pekasolar_FHW',
                       WPDModelPure(unit={'te': 'degC', 'out': 'kg m**-3'}).train(
                           os.path.join(raw_data_dir, 'FHW, Pekasolar', 'Pekasolar, pdf export, density.csv')),
                       WPDModelPure(unit={'te': 'degC', 'out': 'J g**-1 K**-1'}).train(
                           os.path.join(raw_data_dir, 'FHW, Pekasolar', 'Pekasolar, pdf export, heat capacity.csv')),
                       manufacturer="Pekasolar",
                       description="Fluid used in plant FHW, Pekasolar. Fixed concentration as used in plant."),
]

coolprop_fluids = [
    CoolPropFluidDefinition(model_type='CoolProp',
                            name='water',
                            manufacturer=None,
                            description='HEOS::water',
                            is_pure=True,
                            ),

    # CoolProp incompressible pure fluids: Removed, these are mostly not relevant for solar thermal
    # http://www.coolprop.org/fluid_properties/Incompressibles.html#id122
    # See also: https://gitlab.com/sunpeek/web-ui/-/issues/110
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='AS10',
    #                         manufacturer=None,
    #                         description='Aspen Temper -10, Potassium acetate/formate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='AS20',
    #                         manufacturer=None,
    #                         description='Aspen Temper -20, Potassium acetate/formate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='AS30',
    #                         manufacturer=None,
    #                         description='Aspen Temper -30, Potassium acetate/formate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='AS40',
    #                         manufacturer=None,
    #                         description='Aspen Temper -40, Potassium acetate/formate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='AS55',
    #                         manufacturer=None,
    #                         description='Aspen Temper -55, Potassium acetate/formate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='DEB',
    #                         manufacturer=None,
    #                         description='Diethylbenzene mixture - Dowtherm J',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='DSF',
    #                         manufacturer=None,
    #                         description='Dynalene SF',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='DowJ',
    #                         manufacturer=None,
    #                         description='DowthermJ',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='DowJ2',
    #                         manufacturer=None,
    #                         description='Dowtherm J, Diethylbenzene mixture',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='DowQ',
    #                         manufacturer=None,
    #                         description='DowthermQ',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='DowQ2',
    #                         manufacturer=None,
    #                         description='Dowtherm Q, Diphenylethane/alkylated aromatics',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='HC10',
    #                         manufacturer=None,
    #                         description='Dynalene HC10',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='HC20',
    #                         manufacturer=None,
    #                         description='Dynalene HC20',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='HC30',
    #                         manufacturer=None,
    #                         description='Dynalene HC30',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='HC40',
    #                         manufacturer=None,
    #                         description='Dynalene HC40',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='HC50',
    #                         manufacturer=None,
    #                         description='Dynalene HC50',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='HCB',
    #                         manufacturer=None,
    #                         description='Hydrocarbon blend - Dynalene MV',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='HCM',
    #                         manufacturer=None,
    #                         description='Hydrocarbon mixture - Gilotherm D12',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='HFE',
    #                         manufacturer=None,
    #                         description='Hydrofluoroether - HFE-7100 3M Novec',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='HFE2',
    #                         manufacturer=None,
    #                         description='HFE-7100, Hydrofluoroether',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='HY20',
    #                         manufacturer=None,
    #                         description='HYCOOL 20, Potassium formate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='HY30',
    #                         manufacturer=None,
    #                         description='HyCool 30, Potassium formate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='HY40',
    #                         manufacturer=None,
    #                         description='HyCool 40, Potassium formate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='HY45',
    #                         manufacturer=None,
    #                         description='HyCool 45, Potassium formate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='HY50',
    #                         manufacturer=None,
    #                         description='HyCool 50, Potassium formate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='NBS',
    #                         manufacturer=None,
    #                         description='NBS, Water',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='NaK',
    #                         manufacturer=None,
    #                         description='Nitrate salt, 0.6 NaNO3 and 0.4 KNO3',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='PBB',
    #                         manufacturer=None,
    #                         description='Pirobloc HTF-BASIC',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='PCL',
    #                         manufacturer=None,
    #                         description='Paracryol, Aliphatic Hydrocarbon',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='PCR',
    #                         manufacturer=None,
    #                         description='Paratherm CR',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='PGLT',
    #                         manufacturer=None,
    #                         description='Paratherm GLT',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='PHE',
    #                         manufacturer=None,
    #                         description='Paratherm HE',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='PHR',
    #                         manufacturer=None,
    #                         description='Paratherm HR',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='PLR',
    #                         manufacturer=None,
    #                         description='Paratherm LR',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='PMR',
    #                         manufacturer=None,
    #                         description='Paratherm MR',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='PMS1',
    #                         manufacturer=None,
    #                         description='Polydimethylsiloxan 1 - Baysilone KT3',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='PMS2',
    #                         manufacturer=None,
    #                         description='Polydimethylsiloxan 2 - Syltherm XLT',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='PNF',
    #                         manufacturer=None,
    #                         description='Paratherm NF',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='PNF2',
    #                         manufacturer=None,
    #                         description='Paratherm NF, Hydrotreated mineral oil',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='S800',
    #                         manufacturer=None,
    #                         description='Syltherm 800',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='SAB',
    #                         manufacturer=None,
    #                         description='Synthetic alkyl benzene - Marlotherm X',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='T66',
    #                         manufacturer=None,
    #                         description='Therminol66',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='T72',
    #                         manufacturer=None,
    #                         description='Therminol72',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='TCO',
    #                         manufacturer=None,
    #                         description='Citrus oil terpene - d-Limonene',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='TD12',
    #                         manufacturer=None,
    #                         description='TherminolD12',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='TVP1',
    #                         manufacturer=None,
    #                         description='TherminolVP1',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='TVP1869',
    #                         manufacturer=None,
    #                         description='Thermogen VP 1869',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='TX22',
    #                         manufacturer=None,
    #                         description='Texatherm22',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='TY10',
    #                         manufacturer=None,
    #                         description='Tyfoxit 1.10, Potassium Acetate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='TY15',
    #                         manufacturer=None,
    #                         description='Tyfoxit 1.15, Potassium Acetate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='TY20',
    #                         manufacturer=None,
    #                         description='Tyfoxit 1.20, Potassium Acetate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='TY24',
    #                         manufacturer=None,
    #                         description='Tyfoxit 1.24, Potassium Acetate',
    #                         is_pure=True,
    #                         ),

    # Default and recommended for water is to use the "HEOS::water" definition
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='Water',
    #                         manufacturer=None,
    #                         description='Fit of EOS from 1 bar to 100 bar',
    #                         is_pure=True,
    #                         ),

    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='XLT',
    #                         manufacturer=None,
    #                         description='SylthermXLT',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='XLT2',
    #                         manufacturer=None,
    #                         description='Syltherm XLT, Polydimethylsiloxan',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='ZS10',
    #                         manufacturer=None,
    #                         description='Zitrec S10, Potassium formate/Sodium propionate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='ZS25',
    #                         manufacturer=None,
    #                         description='Zitrec S25, Potassium formate/Sodium propionate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='ZS40',
    #                         manufacturer=None,
    #                         description='Zitrec S40, Potassium formate/Sodium propionate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='ZS45',
    #                         manufacturer=None,
    #                         description='Zitrec S45, Potassium formate/Sodium propionate',
    #                         is_pure=True,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='ZS55',
    #                         manufacturer=None,
    #                         description='Zitrec S55, Potassium formate/Sodium propionate',
    #                         is_pure=True,
    #                         ),

    # CoolProp incompressible mass-based binary fluids: Removed, these are mostly not relevant for solar thermal
    # http://www.coolprop.org/fluid_properties/Incompressibles.html#id123
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='FRE',
    #                         manufacturer=None,
    #                         description='Freezium, Potassium Formate',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='IceEA',
    #                         manufacturer=None,
    #                         description='Ice slurry with Ethanol',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='IceNA',
    #                         manufacturer=None,
    #                         description='Ice slurry with NaCl',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='IcePG',
    #                         manufacturer=None,
    #                         description='Ice slurry with Propylene Glycol',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='LiBr',
    #                         manufacturer=None,
    #                         description='Lithium-bromide solution - aq',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MAM',
    #                         manufacturer=None,
    #                         description='Ammonia (NH3) - aq',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MAM2',
    #                         manufacturer=None,
    #                         description='Melinder, Ammonia',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MCA',
    #                         manufacturer=None,
    #                         description='Calcium Chloride (CaCl2) - aq',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MCA2',
    #                         manufacturer=None,
    #                         description='Melinder, Calcium Chloride',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MEA',
    #                         manufacturer=None,
    #                         description='Ethyl Alcohol (Ethanol) - aq',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MEA2',
    #                         manufacturer=None,
    #                         description='Melinder, Ethanol',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MEG',
    #                         manufacturer=None,
    #                         description='Ethylene Glycol - aq',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MEG2',
    #                         manufacturer=None,
    #                         description='Melinder, Ethylene Glycol',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MGL',
    #                         manufacturer=None,
    #                         description='Glycerol - aq',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MGL2',
    #                         manufacturer=None,
    #                         description='Melinder, Glycerol',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MITSW',
    #                         manufacturer=None,
    #                         description='MIT Seawater',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MKA',
    #                         manufacturer=None,
    #                         description='Potassium Acetate (CH3CO2K) - aq',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MKA2',
    #                         manufacturer=None,
    #                         description='Melinder, Potassium Acetate',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MKC',
    #                         manufacturer=None,
    #                         description='Potassium Carbonate (K2CO3) - aq',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MKC2',
    #                         manufacturer=None,
    #                         description='Melinder, Potassium Carbonate',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MKF',
    #                         manufacturer=None,
    #                         description='Potassium Formate (CHKO2) - aq',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MLI',
    #                         manufacturer=None,
    #                         description='Lithium Chloride (LiCl) - aq',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MMA',
    #                         manufacturer=None,
    #                         description='Methyl Alcohol (Methanol) - aq',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MMA2',
    #                         manufacturer=None,
    #                         description='Melinder, Methanol',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MMG',
    #                         manufacturer=None,
    #                         description='MgCl2 - aq',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MMG2',
    #                         manufacturer=None,
    #                         description='Melinder, Magnesium Chloride',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MNA',
    #                         manufacturer=None,
    #                         description='Sodium Chloride (NaCl) - aq',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MNA2',
    #                         manufacturer=None,
    #                         description='Melinder, Sodium Chloride',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MPG',
    #                         manufacturer=None,
    #                         description='Propylene Glycol - aq',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='MPG2',
    #                         manufacturer=None,
    #                         description='Melinder, Propylene Glycol',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='VCA',
    #                         manufacturer=None,
    #                         description='VDI, Calcium Cloride',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='VKC',
    #                         manufacturer=None,
    #                         description='VDI, Potassium Carbonate',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='VMA',
    #                         manufacturer=None,
    #                         description='VDI, Methanol',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='VMG',
    #                         manufacturer=None,
    #                         description='VDI, Magnesium Chloride',
    #                         is_pure=False,
    #                         ),
    # CoolPropFluidDefinition(model_type='CoolProp',
    #                         name='VNA',
    #                         manufacturer=None,
    #                         description='VDI, Sodium Chloride',
    #                         is_pure=False,
    #                         ),

    CoolPropFluidDefinition(model_type='CoolProp',
                            name='AEG',
                            manufacturer=None,
                            description='ASHRAE, Ethylene Glycol',
                            is_pure=False,
                            ),
    CoolPropFluidDefinition(model_type='CoolProp',
                            name='AKF',
                            manufacturer=None,
                            description='Antifrogen KF, Potassium Formate',
                            is_pure=False,
                            ),
    CoolPropFluidDefinition(model_type='CoolProp',
                            name='AL',
                            manufacturer=None,
                            description='Antifrogen L, Propylene Glycol',
                            is_pure=False,
                            ),
    CoolPropFluidDefinition(model_type='CoolProp',
                            name='AN',
                            manufacturer=None,
                            description='Antifrogen N, Ethylene Glycol',
                            is_pure=False,
                            ),
    CoolPropFluidDefinition(model_type='CoolProp',
                            name='APG',
                            manufacturer=None,
                            description='ASHRAE, Propylene Glycol',
                            is_pure=False,
                            ),
    CoolPropFluidDefinition(model_type='CoolProp',
                            name='GKN',
                            manufacturer=None,
                            description='Glykosol N, Ethylene Glycol',
                            is_pure=False,
                            ),
    CoolPropFluidDefinition(model_type='CoolProp',
                            name='PK2',
                            manufacturer=None,
                            description='Pekasol 2000, K acetate/formate',
                            is_pure=False,
                            ),
    CoolPropFluidDefinition(model_type='CoolProp',
                            name='PKL',
                            manufacturer=None,
                            description='Pekasol L, Propylene Glycol',
                            is_pure=False,
                            ),
    CoolPropFluidDefinition(model_type='CoolProp',
                            name='ZAC',
                            manufacturer=None,
                            description='Zitrec AC, Corrosion Inhibitor',
                            is_pure=False,
                            ),
    CoolPropFluidDefinition(model_type='CoolProp',
                            name='ZFC',
                            manufacturer=None,
                            description='Zitrec FC, Propylene Glycol',
                            is_pure=False,
                            ),
    CoolPropFluidDefinition(model_type='CoolProp',
                            name='ZLC',
                            manufacturer=None,
                            description='Zitrec LC, Propylene Glycol',
                            is_pure=False,
                            ),
    CoolPropFluidDefinition(model_type='CoolProp',
                            name='ZM',
                            manufacturer=None,
                            description='Zitrec M, Ethylene Glycol',
                            is_pure=False,
                            ),
    CoolPropFluidDefinition(model_type='CoolProp',
                            name='ZMC',
                            manufacturer=None,
                            description='Zitrec MC, Ethylene Glycol',
                            is_pure=False,
                            ),
]

all_definitions = coolprop_fluids + wpd_fluids


def get_definition(name):
    for fluid in all_definitions:
        if fluid.name == name or name in fluid.description:
            return fluid
